@@ -1,11 +1,8 @@
 from typing import Optional
-import ast
 
-from robot.api.parsing import (
-    ModelTransformer,
-    EmptyLine,
-    Token
-)
+from robot.api.parsing import ModelTransformer, EmptyLine, Token
+
+from robotidy.utils import is_suite_templated
 
 
 class NormalizeNewLines(ModelTransformer):
@@ -24,9 +21,18 @@ class NormalizeNewLines(ModelTransformer):
 
     If the suite contains Test Template tests will not be separated by empty lines unless ``separate_templated_tests``
     is set to True.
+
+    See https://robotidy.readthedocs.io/en/latest/transformers/NormalizeNewLines.html for more examples.
     """
-    def __init__(self, test_case_lines: int = 1, keyword_lines: Optional[int] = None, section_lines: int = 1,
-                 separate_templated_tests: bool = False, consecutive_lines: int = 1):
+
+    def __init__(
+        self,
+        test_case_lines: int = 1,
+        keyword_lines: Optional[int] = None,
+        section_lines: int = 1,
+        separate_templated_tests: bool = False,
+        consecutive_lines: int = 1,
+    ):
         self.test_case_lines = test_case_lines
         self.keyword_lines = keyword_lines if keyword_lines is not None else test_case_lines
         self.section_lines = section_lines
@@ -38,7 +44,7 @@ class NormalizeNewLines(ModelTransformer):
         self.templated = False
 
     def visit_File(self, node):  # noqa
-        self.templated = not self.separate_templated_tests and self.is_templated(node)
+        self.templated = not self.separate_templated_tests and is_suite_templated(node)
         self.last_section = node.sections[-1] if node.sections else None
         return self.generic_visit(node)
 
@@ -74,7 +80,7 @@ class NormalizeNewLines(ModelTransformer):
         tokens = []
         for line in node.lines:
             if line[-1].type == Token.EOL:
-                line[-1].value = '\n'  # TODO: use global formatting in the future
+                line[-1].value = "\n"  # TODO: use global formatting in the future
             tokens.extend(line)
         node.tokens = tokens
         return node
@@ -86,7 +92,7 @@ class NormalizeNewLines(ModelTransformer):
 
     @staticmethod
     def trim_trailing_empty_lines(node):
-        if not hasattr(node, 'body'):
+        if not hasattr(node, "body"):
             return
         while node.body and isinstance(node.body[-1], EmptyLine):
             node.body.pop()
@@ -107,18 +113,3 @@ class NormalizeNewLines(ModelTransformer):
             if empty_count <= self.consecutive_lines:
                 nodes.append(child)
         node.body = nodes
-
-    @staticmethod
-    def is_templated(node):
-        template_finder = TestTemplateFinder()
-        template_finder.visit(node)
-        return template_finder.templated
-
-
-class TestTemplateFinder(ast.NodeVisitor):
-    def __init__(self):
-        self.templated = False
-
-    def visit_TestTemplate(self, node):  # noqa
-        if node.value:
-            self.templated = True
